@@ -22,62 +22,53 @@
 #define IPBLOCKINGPREFPAGE_H
 
 #include <interfaces/prefpageinterface.h>
-#include "ipblockingpref.h"
-#include "ipfilterplugin.h"
 #include <interfaces/coreinterface.h>
 #include <qthread.h>
-#include <qobject.h>
+#include "ui_ipblockingprefpage.h"
+#include "ipfilterplugin.h"
 
 class KProgress;
+class KJob;
 
 namespace kt
 {
 	class IPFilterPlugin;
-	class IPBlockingPrefPage;
-	
-	/**
-	@author Ivan Vasic
-	*/
-	class IPBlockingPrefPageWidget : public IPBlockingPref
-	{
-		public:
-			IPBlockingPrefPageWidget(QWidget *parent = 0);
-			void apply();
-			void convert();
-			void setPlugin(IPFilterPlugin* p);
-			void setPrefPage(IPBlockingPrefPage* p);
-			
-			//used with ConvertThread to enable/disable controls while converting
-			void setConverting(bool enable);
-			
-		public slots:
-    		virtual void btnDownload_clicked();
-    		virtual void checkUseLevel1_toggled(bool);
-			
-		private:
-			IPFilterPlugin* m_plugin;
-			IPBlockingPrefPage* m_prefpage;
-	};
 	
 	/**
 	 * @author Ivan Vasic
 	 * @brief IPBlocking plugin interface page
 	 **/
-	class IPBlockingPrefPage : public PrefPageInterface
+	class IPBlockingPrefPage : public PrefPageInterface,public Ui_IPBlockingPrefPage
 	{
-		public:
-			IPBlockingPrefPage(CoreInterface* core, IPFilterPlugin* p);
-			virtual ~IPBlockingPrefPage();
+		Q_OBJECT
+	public:
+		IPBlockingPrefPage(CoreInterface* core, IPFilterPlugin* p);
+		virtual ~IPBlockingPrefPage();
+		
+	
+		virtual void loadSettings();
+		virtual void loadDefaults();
+		virtual void updateSettings();
 			
-			virtual bool apply();
-			virtual void createWidget(QWidget* parent);
-			virtual void updateData();
-			virtual void deleteWidget();
+	private slots:
+		void btnDownloadClicked();
+		void checkUseLevel1Toggled(bool);
+		void downloadFileFinished(KJob*);
+		void convert(KJob*);
+		void extract(KJob*);
+		void makeBackupFinished(KJob* );
+		void revertBackupFinished(KJob*);
+		
+		
+	private:
+		void convert();
+		void cleanUp(const QString & path);
+		void cleanUpFiles();
+		void restoreGUI();
 
-		private:
-			CoreInterface* m_core;
-			IPBlockingPrefPageWidget* widget;
-			IPFilterPlugin* m_plugin;
+	private:
+		CoreInterface* m_core;
+		IPFilterPlugin* m_plugin;
 	};
 }
 #endif
